summaryrefslogtreecommitdiffstats
path: root/ssl/s3_lib.c
diff options
context:
space:
mode:
authorMatt Caswell <matt@openssl.org>2016-09-05 17:34:04 +0100
committerMatt Caswell <matt@openssl.org>2016-09-13 09:41:21 +0100
commitae2f7b37da3640f4cfa5df0e5bad2aa2ca5f1ba3 (patch)
tree547eb74809823ee123d66281a35f8e16884e7b19 /ssl/s3_lib.c
parent2c7b4dbc1af9cfae4e4afd7c4a07db95a1133a6a (diff)
Rename PACKETW to WPACKET
To avoid confusion with the read PACKET structure. Reviewed-by: Rich Salz <rsalz@openssl.org>
Diffstat (limited to 'ssl/s3_lib.c')
-rw-r--r--ssl/s3_lib.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/ssl/s3_lib.c b/ssl/s3_lib.c
index 9f7c6cc782..7cec0116c0 100644
--- a/ssl/s3_lib.c
+++ b/ssl/s3_lib.c
@@ -2790,16 +2790,16 @@ int ssl3_set_handshake_header(SSL *s, int htype, unsigned long len)
}
/*
* Temporary name. To be renamed ssl3_set_handshake_header() once all PACKETW
* conversion is complete. The old ssl3_set_handshake_heder() can be deleted
* at that point.
* TODO - RENAME ME
*/
-int ssl3_set_handshake_header2(SSL *s, PACKETW *pkt, PACKETW *body, int htype)
+int ssl3_set_handshake_header2(SSL *s, WPACKET *pkt, WPACKET *body, int htype)
{
/* Set the content type and 3 bytes for the message len */
- if (!PACKETW_put_bytes(pkt, htype, 1)
- || !PACKETW_get_sub_packet_len(pkt, body, 3))
+ if (!WPACKET_put_bytes(pkt, htype, 1)
+ || !WPACKET_get_sub_packet_len(pkt, body, 3))
return 0;
return 1;
@@ -3573,7 +3573,7 @@ const SSL_CIPHER *ssl3_get_cipher_by_char(const unsigned char *p)
/*
* Old version of the ssl3_put_cipher_by_char function used by code that has not
* yet been converted to PACKETW yet. It will be deleted once PACKETW conversion
* is complete.
* TODO - DELETE ME
*/
@@ -3591,14 +3591,14 @@ int ssl3_put_cipher_by_char_old(const SSL_CIPHER *c, unsigned char *p)
return (2);
}
-int ssl3_put_cipher_by_char(const SSL_CIPHER *c, PACKETW *pkt, size_t *len)
+int ssl3_put_cipher_by_char(const SSL_CIPHER *c, WPACKET *pkt, size_t *len)
{
if ((c->id & 0xff000000) != 0x03000000) {
*len = 0;
return 1;
}
- if (!PACKETW_put_bytes(pkt, c->id & 0xffff, 2))
+ if (!WPACKET_put_bytes(pkt, c->id & 0xffff, 2))
return 0;
*len = 2;
@@ -2790,16 +2790,16 @@ int ssl3_set_handshake_header(SSL *s, int htype, unsigned long len)
}
/*
- * Temporary name. To be renamed ssl3_set_handshake_header() once all PACKETW
+ * Temporary name. To be renamed ssl3_set_handshake_header() once all WPACKET
* conversion is complete. The old ssl3_set_handshake_heder() can be deleted
* at that point.
@@ -3573,7 +3573,7 @@ const SSL_CIPHER *ssl3_get_cipher_by_char(const unsigned char *p)
/*
* Old version of the ssl3_put_cipher_by_char function used by code that has not
- * yet been converted to PACKETW yet. It will be deleted once PACKETW conversion
+ * yet been converted to WPACKET yet. It will be deleted once WPACKET conversion
* is complete.
* TODO - DELETE ME